#
# spec file for package python-Flask-Cache
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Flask-Cache
Version:        0.13.1
Release:        lp152.2.3
Summary:        Cache support for Flask
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/thadeusb/flask-cache
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Cache/Flask-Cache-%{version}.tar.gz
Patch0:         Flask-Cache-fix-namespace.patch
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module base}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
BuildArch:      noarch
%python_subpackages

%description
Adds cache support to your Flask application

%package doc
Summary:        Documentation for python-Flask-Cache
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
This package contains HTML documentation, including tutorials and API
reference for python-Flask-Cache.

%prep
%setup -q -n Flask-Cache-%{version}
%patch0 -p1

%build
%python_build
cd docs && make html && rm _build/html/.buildinfo # Generate HTML documentation

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc CHANGES README
%{python_sitelib}/*

%files %{python_files doc}
%doc docs/_build/html

%changelog
* Tue Jun  5 2018 hpj@urpla.net
- clean up spec
* Mon Jun  4 2018 hpj@urpla.net
- fix namespace with Flask-Cache-fix-namespace.patch
* Sat Oct  7 2017 arun@gmx.de
- update to single spec
- update copyright year
* Thu Sep 15 2016 toddrme2178@gmail.com
- Update to Version 0.13
  - Port to Python >= 3.3 (requiring Python 2.6/2.7 for 2.x).
  - Fixed bug with using per-memoize timeouts greater than the default timeout
  - Added better support for per-instance memoization.
  - Various bug fixes
- Update to Version 0.12
  - Changes jinja2 cache templates to use stable predictable keys. Previously
    the key for a cache tag included the line number of the template, which made
    it difficult to predict what the key would be outside of the application.
  - Adds config variable `CACHE_NO_NULL_WARNING` to silence warning messages
    when using 'null' cache as part of testing.
  - Adds passthrough to clear entire cache backend.
- Update to Version 0.11.1
  - Bugfix for using memoize on instance methods.
  The previous key was id(self), the new key is repr(self)
- Update to Version 0.11
  - Fail gracefully in production if cache backend raises an exception.
  - Support for redis DB number
  - Jinja2 templatetag cache now concats all args together into a single key
    instead of treating each arg as a separate key name.
  - Added delete memcache version hash function
  - Support for multiple cache objects on a single app again.
  - Added SpreadSASLMemcached, if a value is greater than the memcached threshold
    which defaults to 1MB, this splits the value across multiple keys.
  - Added support to use URL to connect to redis.
- Update to Version 0.10.1
  - Added warning message when using cache type of 'null'
  - Changed imports to relative instead of absolute for AppEngine compatibility
- Update to Version 0.10.0
  - Added `saslmemcached` backend to support Memcached behind SASL authentication.
  - Fixes a bug with memoize when the number of args != number of kwargs
- Update to Version 0.9.2
  - Bugfix with default kwargs
- Update to Version 0.9.1- Update to
  - Fixes broken memoized on functions that use default kwargs
- Update to Version 0.9.0
  - Fixes memoization to work on methods.
- Update to Version 0.8.0
  - Migrated to the new flask extension naming convention of flask_cache instead of flaskext.cache
  - Removed unnecessary dependencies in setup.py file.
  - Documentation updates
- Update to Version 0.7.0
  - Allows multiple cache objects to be instantiated with different configuration values.
- Update to Version 0.6.0
  - Memoization is now safer for multiple applications using the same backing store.
  - Removed the explicit set of NullCache if the Flask app is set testing=True
  - Swapped Conditional order for key_prefix
- Update to Version 0.5.0
  - Deleting memoized functions now properly functions in production
    environments where multiple instances of the application are running.
  - get_memoized_names and get_memoized_keys have been removed.
  - Added ``make_name`` to memoize, make_name is an optional callable that can be passed
    to memoize to modify the cache_key that gets generated.
  - Added ``unless`` to memoize, this is the same as the unless parameter in ``cached``
  - memoization now converts all kwargs to positional arguments, this is so that
    when a function is called multiple ways, it would evaluate to the same cache_key
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 0.4.0:
  + Added attributes for uncached, make_cache_key, cache_timeout
    to the decorated functions.
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.3.4:
  + UTF-8 encoding of cache key
  + key_prefix argument of the cached decorator now supports callables.
* Wed Jul 20 2011 saschpe@gmx.de
- Initial version
